@@ -13,16 +13,7 @@ logger = logging.getLogger(__name__)
 class SME_DLL:
     """ Object Oriented interface for the SME C library """
 
-    _instance = None
-
-    def __new__(cls, *args, **kwargs):
-        if cls._instance is None:
-            cls._instance = object.__new__(cls)
-            SME_DLL.init(cls._instance, *args, **kwargs)
-        return cls._instance
-
-    @staticmethod
-    def init(self, libfile=None, datadir=None):
+    def __init__(self, libfile=None, datadir=None):
         #:LineList: Linelist passed to the library
         self.linelist = None
         #:int: Number of mu points passed to the library
@@ -169,11 +160,14 @@ class SME_DLL:
         gamma6 : float
             van der Waals scaling factor
         """
+        logger.debug("Setting Van der Waals scale in smelib")
         self.lib.SetVWscale(gamma6, type="double")
         self.vw_scale = gamma6
 
     def SetH2broad(self, h2_flag=True):
         """ Set flag for H2 molecule """
+        logger.debug("Setting H2 broadening in smelib")
+
         if h2_flag:
             self.lib.SetH2broad()
             self.h2broad = True
@@ -213,6 +207,7 @@ class SME_DLL:
             atomic.shape[0] == 8
         ), f"Got wrong Linelist shape, expected ({nlines}, 8) but got {atomic.shape}"
 
+        logger.debug("Passing linelist to smelib")
         self.lib.InputLineList(
             nlines, species, atomic, type=("int", "string", "double")
         )
@@ -262,6 +257,7 @@ class SME_DLL:
 
         atomic = atomic.T
 
+        logger.debug("Updating linelist in smelib")
         self.lib.UpdateLineList(
             nlines, species, atomic, index, type=("int", "str", "double", "short")
         )
@@ -287,8 +283,21 @@ class SME_DLL:
             raise ValueError("Turbulence velocity must be positive or zero")
 
         try:
-            motype = atmo.depth
-            depth = atmo[motype]
+
+            #   MOTYPE==0   means depth scale is "Tau", plane-parralel
+            #   MOTYPE==1   means depth scale is "Rhox", plane-parralel
+            #   MOTYPE==3   means depth scale is "RhoX", spherical
+            #   MOTYPE==-1  fake value used with the call to OPMTRX get just
+            #               just the line opacities
+
+            if atmo.geom == "SPH":
+                # Spherical only supports RHOX
+                depth = atmo["RHOX"]
+                motype = "SPH"
+            else:
+                motype = atmo.depth
+                depth = atmo[motype]
+
             ndepth = len(depth)
             t = atmo.temp
             xne = atmo.xne
@@ -317,11 +326,12 @@ class SME_DLL:
                 radius = atmo.radius
                 height = atmo.height
                 motype = "SPH"
-                args = args[:5] + [radius] + args[5:] + [height]
-                type = type[:5] + "d" + type[5:] + "d"
+                args = args[:4] + [motype, radius] + args[5:] + [height]
+                type = type[:4] + "ud" + type[5:] + "d"
         except AttributeError as ae:
             raise TypeError(f"atmo has to be an Atmo type, {ae}")
 
+        logger.debug("Inputing atmosphere model to smelib")
         self.lib.InputModel(*args, type=type)
 
         self.teff = teff
@@ -347,6 +357,9 @@ class SME_DLL:
         # metallicity is included in the abundance class, ignored in function call
         abund = abund("sme", raw=True)
         assert isinstance(abund, np.ndarray)
+        abund[np.isnan(abund)] = -99
+
+        logger.debug("Inputing abundances to smelib")
         self.lib.InputAbund(abund, type="double")
 
         self.abund = abund
@@ -456,6 +469,7 @@ class SME_DLL:
         ion : int
             flag that determines the behaviour of the C function
         """
+        logger.debug("Calculating ionization in smelib")
         self.lib.Ionization(ion, type="short", raise_error=False, raise_warning=True)
         self.ion = ion
 
@@ -564,9 +578,11 @@ class SME_DLL:
         sint_seg = np.zeros((nwmax, nmu))  # line+continuum intensities
         cint_seg = np.zeros((nwmax, nmu))  # all continuum intensities
         cintr_seg = np.zeros((nmu))  # red continuum intensity
+        nw = np.array([nw])
 
         type = "sdddiiddddss"  # s: short, d:double, i:int, u:unicode (string)
 
+        logger.debug("Starting radiative Transfer calculations in smelib")
         self.lib.Transf(
             nmu,
             mu,
@@ -582,9 +598,7 @@ class SME_DLL:
             long_continuum,
             type=type,
         )
-
-        if nw == 0:
-            nw = np.count_nonzero(wint_seg)
+        nw = nw[0]
 
         wint_seg = wint_seg[:nw]
         sint_seg = sint_seg[:nw, :].T
@@ -696,13 +710,13 @@ class SME_DLL:
             raise TypeError("Departure coefficient matrix is not an array")
 
         bmat = np.atleast_2d(bmat)
-        if bmat.shape[0] != 2:
+        if bmat.shape[1] != 2:
             raise ValueError(
-                f"Departure coefficient matrix has the wrong shape, expected (2, {ndepth}) but got {bmat.shape} instead"
+                f"Departure coefficient matrix has the wrong shape, expected ({ndepth}, 2) but got {bmat.shape} instead"
             )
-        if bmat.shape[1] != ndepth:
+        if bmat.shape[0] != ndepth:
             raise ValueError(
-                f"Departure coefficient matrix has the wrong shape, expected (2, {ndepth}) but got {bmat.shape} instead"
+                f"Departure coefficient matrix has the wrong shape, expected ({ndepth}, 2) but got {bmat.shape} instead"
             )
 
         if not isinstance(lineindex, (int, np.integer)):
