@@ -2,7 +2,9 @@
 
 import pytest
 
+import os
 from os.path import dirname
+import tempfile
 
 import numpy as np
 
@@ -10,7 +12,7 @@ from pysme.sme import SME_Structure as SME_Struct
 from pysme.iliffe_vector import Iliffe_vector
 from pysme.linelist.vald import ValdFile
 from pysme.sme_synth import SME_DLL
-from pysme.nlte import nlte
+from pysme.nlte import nlte, DirectAccessFile
 from pysme.synthesize import Synthesizer, synthesize_spectrum
 from pysme.config import Config
 from pysme.abund import Abund
@@ -44,12 +46,12 @@ def test_activate_nlte():
     assert len(sme.nlte.elements) == 0
 
     # Add an element
-    sme.nlte.set_nlte("Ca")
+    sme.nlte.set_nlte("Ca", "marcs2012p_t1.0_Ca.grd")
     assert len(sme.nlte.elements) == 1
     assert "Ca" in sme.nlte.elements
 
     # Add it again, shouldn't change anything
-    sme.nlte.set_nlte("Ca")
+    sme.nlte.set_nlte("Ca", "marcs2012p_t1.0_Ca.grd")
     assert len(sme.nlte.elements) == 1
     assert "Ca" in sme.nlte.elements
 
@@ -86,7 +88,7 @@ def test_activate_nlte():
 def test_run_with_nlte():
     # NOTE sme structure must have long format for NLTE
     sme = make_minimum_structure()
-    sme.nlte.set_nlte("Ca")
+    sme.nlte.set_nlte("Ca", "marcs2012p_t1.0_Ca.grd")
 
     sme2 = synthesize_spectrum(sme)
 
@@ -101,7 +103,7 @@ def test_run_with_nlte():
 def test_dll(lfs_atmo, lfs_nlte):
     sme = make_minimum_structure()
     elem = "Ca"
-    sme.nlte.set_nlte(elem)
+    sme.nlte.set_nlte(elem, "marcs2012p_t1.0_Ca.grd")
 
     libsme = SME_DLL()
     libsme.ResetNLTE()
@@ -117,7 +119,7 @@ def test_dll(lfs_atmo, lfs_nlte):
     for lr, li in zip(linerefs, lineindices):
         if lr[0] != -1 and lr[1] != -1:
             counter += 1
-            libsme.InputNLTE(bmat[:, lr].T, li)
+            libsme.InputNLTE(bmat[:, lr], li)
 
     flags = libsme.GetNLTEflags()
     assert np.any(flags)
@@ -138,10 +140,38 @@ def test_dll(lfs_atmo, lfs_nlte):
         libsme.InputNLTE(None, 0)
 
     with pytest.raises(TypeError):
-        libsme.InputNLTE(bmat[:, [0, 1]].T, 0.1)
+        libsme.InputNLTE(bmat[:, [0, 1]], 0.1)
 
     with pytest.raises(ValueError):
         libsme.InputNLTE([0, 1], 10)
 
     with pytest.raises(ValueError):
-        libsme.InputNLTE(bmat[:, [0, 1]].T, -10)
+        libsme.InputNLTE(bmat[:, [0, 1]], -10)
+
+
+@pytest.fixture
+def temp():
+    file = tempfile.NamedTemporaryFile(delete=False)
+    yield file.name
+    try:
+        os.remove(file)
+    except:
+        pass
+
+
+def test_read_write_direct_access_file(temp: str):
+    content = {
+        "hello": "world",
+        "I": ["have", "the", "high", "ground"],
+        "teff": np.arange(100),
+    }
+
+    DirectAccessFile.write(temp, **content)
+    daf = DirectAccessFile(temp)
+
+    for key, value in content.items():
+        vf = daf[key]
+        if np.issubdtype(vf.dtype, np.dtype("S")):
+            vf = np.char.decode(vf)
+
+        assert np.all(vf == value)
